const _ = require('lodash');
const moment = require('moment');
export const format = 'YYYY-MM-DD';
/**
 * 转换为常规时间格式 YYYY-MM-DD
 * @param {String} year 年
 * @param {String} date 月日: x.x格式
 * @returns
 */
export const toRegularDate = (year, date) => {
  const dateStr = `${year}.${date}`;
  const formatStr = moment(dateStr).format(format);
  return formatStr;
};
/**
 * 根据时间参数获取当前月的最后一天
 * @param {String} date YYYY-MM-DD格式时间
 */
export const getMonthLastDay = date => {
  const lastDay = moment(`${moment(date).year()}-${moment(date).month() + 1}-01`)
    .add(1, 'M')
    .subtract(1, 'd')
    .format(format);
  return lastDay;
};
/**
 * 根据时间参数获取当前月的第一天
 * @param {String} date YYYY-MM-DD格式时间
 */
export const getMonthFirstDay = date => {
  const firstDay = moment(`${moment(date).year()}-${moment(date).month() + 1}-01`).format(format);
  return firstDay;
};
/**
 * 计算两天相差天数
 * @param {String} start 开始时间
 * @param {String} end 结束时间
 * @returns 
 */
export const getDays = (start, end) => {
  return moment(end).diff(start, 'd')
};

/**
 * 判断日期是否在开始时间-结束时间范围内
 * @param {String} start 开始时间
 * @param {String} end 结束时间
 * @param {String} date 日期
 * @returns
 */
export const inDateRange = (start, end, date) => {
  return moment(date).isBetween(start, end, null, '[]');
};
/**
 * 判断两天是否一致
 * @param {String} start 开始时间
 * @param {String} date 日期
 * @returns
 */
export const checkIsSame = (start, date) => {
  const result = moment(date).isSame(start);
  return result;
};
export const coreResult = {
  /**同月且第一天 */
  SMFD: 'same_month_first_day',
  /**同月且非第一天 */
  SMNFD: 'same_month_not_first_day',
  /**开始时间同月且第一天 */
  STMFD: 'start_month_first_day',
  /**开始时间同月且非第一天 */
  STMNFD: 'start_month_not_first_day',
  /**结束时间同月且第一天 */
  ENDMFD: 'end_month_first_day',
  /**结束时间同月且非第一天 */
  ENDMNFD: 'end_month_not_first_day',
};
/**
 * 核心判断逻辑
 * @param {String} start 开始时间
 * @param {String} end 结束时间
 * @param {String} date 当前日期
 * @param {String} month 当前月
 * @returns {coreResult}
 */
export const outPutCore = (start, end, date, month) => {
  let result;
  const sm = moment(start).month() + 1;
  const em = moment(end).month() + 1;
  if (sm === em) {
    // 同月
    const isFirstDay = checkIsSame(start, date);
    if (isFirstDay) result = coreResult.SMFD;
    else result = coreResult.SMNFD;
  } else if (sm === month) {
    // 开始时间月
    const isFirstDay = checkIsSame(start, date);
    if (isFirstDay) result = coreResult.STMFD;
    else result = coreResult.STMNFD;
  } else if (em === month) {
    // 结束时间月
    const firstDay = moment(`${moment(end).year()}-${moment(end).month() + 1}-01`).format(format);
    if (moment(date).isSame(firstDay)) result = coreResult.ENDMFD;
    else result = coreResult.ENDMNFD;
  }
  return result;
};
